@@ -22,14 +22,6 @@ class InventoryLargeChest(Inventory):
         else:
             return self.__upperChest.getStackInSlot(slot)
 
-    def decrStackSize(self, slot, size):
-        if slot >= self.__upperChest.getSizeInventory():
-            return self.__lowerChest.decrStackSize(
-                slot - self.__upperChest.getSizeInventory(), size
-            )
-        else:
-            return self.__upperChest.decrStackSize(slot, size)
-
     def setInventorySlotContents(self, slot, stack):
         if slot >= self.__upperChest.getSizeInventory():
             self.__lowerChest.setInventorySlotContents(
@@ -37,3 +29,6 @@ class InventoryLargeChest(Inventory):
             )
         else:
             self.__upperChest.setInventorySlotContents(slot, stack)
+
+    def getInventoryStackLimit(self):
+        return self.__upperChest.getInventoryStackLimit()
