@@ -5,7 +5,7 @@ from mc.net.minecraft.game.Inventory import Inventory
 from nbtlib.tag import Compound, String, Byte, List
 
 class TileEntityChest(TileEntity, Inventory):
-    CHEST_STACK_LIMIT = 100
+    CHEST_STACK_LIMIT = 64
 
     def __init__(self):
         self.__chestContents = [None] * 36
@@ -18,6 +18,8 @@ class TileEntityChest(TileEntity, Inventory):
 
     def setInventorySlotContents(self, slot, stack):
         self.__chestContents[slot] = stack
+        if stack:
+            stack.stackSize = min(stack.stackSize, TileEntityChest.CHEST_STACK_LIMIT)
 
     def getInvName(self):
         return 'Chest'
